==> nextcloud-29.0.12.tgz: nextcloud/apps/files_downloadlimit/l10n/sr.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Ograničenje preuzimanja datoteka ",
    "File link share download limit" : "Ograničenje preuzimanja deljenja linka datoteke",
    "This app allows limiting the number of downloads for external link shares." : "Ова апликација омогућава ограничавање броја преузимања за дељења спољним линком.",
    "Limit downloads" : "Ograniči preuzimanja",
    "Set download limit" : "Podesite ograničenje preuzimanja",
    "Setting a new limit will reset the download count" : "Постављање нове границе ће ресетовати број преузимања",
    "The minimum limit is 1" : "Минимална граница је 1",
    "Failed to set download limit" : "Није успело постављање границе преузимања",
    "Failed to remove download limit" : "Није успело уклањање границе преузимања",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["дозвољено је још 1 преостало преузимање","дозвољена су још {count} преостала преузимања","дозвољено је још {count} преосталих преузимања"],
    "Download limit" : "Ограничење преузимања",
    "Configure the default download limit for external shares." : "Подешавање подразумеваног ограничења за спољна дељења.",
    "Set default download limit" : "Постави подразумевано ограничење преузимања",
    "Failed to set default download limit" : "Није успело постављање подразумеване границе преузимања",
    "You have reached the maximum amount of downloads allowed" : "Dostigli ste maksimalnu dozvoljenu količinu preuzimanja",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Ovo deljenje ima ograničen broj preuzimanja. Da li ste sigurni da želite da pokrenete novo preuzimanje?"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/files_downloadlimit/l10n/sr.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Ograničenje preuzimanja datoteka ",
    "File link share download limit" : "Ograničenje preuzimanja deljenja linka datoteke",
    "This app allows limiting the number of downloads for external link shares." : "Ова апликација омогућава ограничавање броја преузимања за дељења спољним линком.",
    "Limit downloads" : "Ograniči preuzimanja",
    "Set download limit" : "Podesite ograničenje preuzimanja",
    "Setting a new limit will reset the download count" : "Постављање нове границе ће ресетовати број преузимања",
    "The minimum limit is 1" : "Минимална граница је 1",
    "Failed to set download limit" : "Није успело постављање границе преузимања",
    "Failed to remove download limit" : "Није успело уклањање границе преузимања",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["дозвољено је још 1 преостало преузимање","дозвољена су још {count} преостала преузимања","дозвољено је још {count} преосталих преузимања"],
    "Download limit" : "Ограничење преузимања",
    "Configure the default download limit for external shares." : "Подешавање подразумеваног ограничења за спољна дељења.",
    "Set default download limit" : "Постави подразумевано ограничење преузимања",
    "Failed to set default download limit" : "Није успело постављање подразумеване границе преузимања",
    "You have reached the maximum amount of downloads allowed" : "Dostigli ste maksimalnu dozvoljenu količinu preuzimanja",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Ovo deljenje ima ograničen broj preuzimanja. Da li ste sigurni da želite da pokrenete novo preuzimanje?",
    "Allow to limit the number of downloads for link shares" : "Dozvolite da ograničite broj preuzimanja za deljenje linkova",
    "This share was limited to {limit} downloads. There is still {countLeft} left allowed." : "Ovo deljenje je ograničeno na {limit} preuzimanja. Još uvek je dozvoljeno {countLeft}."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
